#include <stdio.h>
#include <errno.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <dirent.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>

#include "db.h"
#include "sbs.h"

void do_commit(char *name);

void
sbs_commit(int argc, char *argv[]) 
{
    char path[PATH_MAX];
    int i;

    if(argc == 2) {
	/* commit the current working directory */
	getcwd(path, PATH_MAX);
	do_commit(path);

    } else {
	/* commit each file or directory */
	for(i = 2; i < argc; i++) {
	    do_commit(argv[i]);
	}
    }
}

void 
do_commit(char *name)
{
    char temppath[PATH_MAX], cwd[PATH_MAX];
    char *path, *ptr;
    char repo_path[PATH_MAX];
    struct stat st;

    if( (getcwd(cwd, PATH_MAX)) == NULL) {
	perror("getcwd");
	exit(1);
    }

    /* construct the path */
    path = get_abs_path(name);

    /* parse the path to determine where the repository tree begins */

    /* check if path is a file or a directory */
    strncpy(temppath, path, sizeof(temppath));
    if( (stat(temppath, &st)) == -1) {
	perror("stat");
	exit(1);
    }
    if(!S_ISDIR(st.st_mode)) {
	/* strip off the file name from the path string */
	if((ptr = rindex(temppath, '/')) == NULL) {
	    fprintf(stderr, "Error: expecting a path, got %s\n", 
		    temppath);  /* shouldn't happen */
	    exit(1);
	}
	*ptr = '\0';
	get_repository_path(repo_path, temppath, PATH_MAX);
	printf("Path in repository is %s\n", repo_path);

	/* Make sure all the directories are created */
	createdirs(repo_path);

	/* add file name back to the repo_path */
	ptr++;
	strncat(repo_path, "/", 2);
	strncat(repo_path, ptr, strlen(ptr) +1);
	
	/* copy the file */

	copy_file(path, unique_name(repo_path));
	
    } else {
	get_repository_path(repo_path, path, PATH_MAX);
	printf("Path in repository is %s\n", repo_path);
	createdirs(repo_path);

	/* copy the dir */
	copy_dir(path, repo_path);
    }

}
